@@ -20,6 +20,7 @@ from typing import (
     Callable,
     Dict,
     Iterable,
+    Mapping,
     Optional,
     Tuple,
     Union,
@@ -120,7 +121,10 @@ class Storage(metaclass=NoPublicConstructor):
 
     def _set_time_diff(self, request_time: float, resp: aiohttp.ClientResponse) -> None:
         response_time = time.time()
-        server_timetuple = parsedate(resp.headers.get("Date"))
+        str_date = resp.headers.get("Date")
+        if not str_date:
+            return
+        server_timetuple = parsedate(str_date)
         if not server_timetuple:
             return
         server_time = datetime.datetime(
@@ -161,7 +165,9 @@ class Storage(metaclass=NoPublicConstructor):
             self._set_time_diff(request_time, resp)
             if resp.headers.get("Content-Type", "").startswith("application/x-ndjson"):
                 async for line in resp.content:
-                    status = json.loads(line)["FileStatus"]
+                    server_message = json.loads(line)
+                    self.check_for_server_error(server_message)
+                    status = server_message["FileStatus"]
                     yield _file_status_from_api_ls(uri, status)
             else:
                 res = await resp.json()
@@ -321,6 +327,15 @@ class Storage(metaclass=NoPublicConstructor):
             queue, self._rm(uri, recursive=recursive, progress=async_progress)
         )
 
+    def check_for_server_error(self, server_message: Mapping[str, Any]) -> None:
+        if "error" in server_message:
+            err_text = server_message["error"]
+            os_errno = server_message.get("errno", None)
+            if os_errno is not None:
+                os_errno = errno.__dict__.get(os_errno, os_errno)
+                raise OSError(os_errno, err_text)
+            raise Exception(err_text)
+
     async def _rm(
         self, uri: URL, *, recursive: bool, progress: _AsyncAbstractDeleteProgress
     ) -> None:
@@ -338,11 +353,12 @@ class Storage(metaclass=NoPublicConstructor):
         ) as resp:
             if resp.headers.get("Content-Type", "").startswith("application/x-ndjson"):
                 async for line in resp.content:
-                    remove_listing = json.loads(line)
+                    server_message = json.loads(line)
+                    self.check_for_server_error(server_message)
                     await progress.delete(
                         StorageProgressDelete(
-                            uri=base_uri / remove_listing["path"].lstrip("/"),
-                            is_dir=remove_listing["is_dir"],
+                            uri=base_uri / server_message["path"].lstrip("/"),
+                            is_dir=server_message["is_dir"],
                         )
                     )
             else:
@@ -359,7 +375,11 @@ class Storage(metaclass=NoPublicConstructor):
     # high-level helpers
 
     async def _iterate_file(
-        self, src: Path, dst: URL, *, progress: _AsyncAbstractFileProgress,
+        self,
+        src: Path,
+        dst: URL,
+        *,
+        progress: _AsyncAbstractFileProgress,
     ) -> AsyncIterator[bytes]:
         loop = asyncio.get_event_loop()
         src_url = URL(src.as_uri())
@@ -435,12 +455,17 @@ class Storage(metaclass=NoPublicConstructor):
         await run_progress(queue, self._upload_file(path, dst, progress=async_progress))
 
     async def _upload_file(
-        self, src_path: Path, dst: URL, *, progress: _AsyncAbstractFileProgress,
+        self,
+        src_path: Path,
+        dst: URL,
+        *,
+        progress: _AsyncAbstractFileProgress,
     ) -> None:
         for retry in retries(f"Fail to upload {dst}"):
             async with retry:
                 await self.create(
-                    dst, self._iterate_file(src_path, dst, progress=progress),
+                    dst,
+                    self._iterate_file(src_path, dst, progress=progress),
                 )
 
     async def upload_dir(
