@@ -7,6 +7,7 @@ from pathlib import Path
 from typing import Any, Dict, Optional
 
 import click
+from aiohttp.client_exceptions import ClientConnectionError
 from prompt_toolkit import PromptSession
 from prompt_toolkit.patch_stdout import patch_stdout
 from yarl import URL
@@ -31,10 +32,11 @@ async def show(root: Root) -> None:
     Print current settings.
     """
     fmt = ConfigFormatter()
-    available_jobs_counts = await root.client.jobs.get_capacity(
-        root.client.config.presets
-    )
-    click.echo(fmt(root.client.config, available_jobs_counts))
+    try:
+        jobs_capacity = await root.client.jobs.get_capacity(root.client.config.presets)
+    except ClientConnectionError:
+        jobs_capacity = {}
+    click.echo(fmt(root.client.config, jobs_capacity))
 
 
 @command()
@@ -84,6 +86,11 @@ def _print_welcome(url: URL) -> None:
     )
 
 
+async def _show_browser(url: URL) -> None:
+    loop = asyncio.get_event_loop()
+    await loop.run_in_executor(None, webbrowser.open_new, str(url))
+
+
 @command(init_client=False)
 @argument("url", required=False, default=DEFAULT_API_URL, type=URL)
 async def login(root: Root, url: URL) -> None:
@@ -93,16 +100,12 @@ async def login(root: Root, url: URL) -> None:
     URL is a platform entrypoint URL.
     """
 
-    async def show_browser(url: URL) -> None:
-        loop = asyncio.get_event_loop()
-        await loop.run_in_executor(None, webbrowser.open_new, str(url))
-
     try:
-        await root.factory.login(show_browser, url=url, timeout=root.timeout)
+        await root.factory.login(_show_browser, url=url, timeout=root.timeout)
     except (ConfigError, FileExistsError):
         await root.factory.logout()
         click.echo("You were successfully logged out.")
-        await root.factory.login(show_browser, url=url, timeout=root.timeout)
+        await root.factory.login(_show_browser, url=url, timeout=root.timeout)
     _print_welcome(url)
 
 
@@ -119,7 +122,7 @@ async def login_with_token(root: Root, token: str, url: URL) -> None:
     try:
         await root.factory.login_with_token(token, url=url, timeout=root.timeout)
     except ConfigError:
-        await root.factory.logout()
+        await root.factory.logout(_show_browser)
         click.echo("You were successfully logged out.")
         await root.factory.login_with_token(token, url=url, timeout=root.timeout)
     _print_welcome(url)
@@ -165,7 +168,7 @@ async def logout(root: Root) -> None:
     """
     Log out.
     """
-    await root.factory.logout()
+    await root.factory.logout(_show_browser)
     click.echo("Logged out")
 
 
